# Use rpmbuild --without checks to disable running the test suite (enabled by default)
%{!?_with_checks:   %{!?_without_checks: %define _with_checks --with-checks}}
%{?_with_checks:    %define enable_checks 1}
%{?_without_checks: %define enable_checks 0}

# Use rpmbuild --without milter to disable building the milter (enabled by default)
# You'll need to do this if you don't have sendmail-devel installed
%{!?_with_milter:   %{!?_without_milter: %define _with_milter --with-milter}}
%{?_with_milter:    %define enable_milter 1}
%{?_without_milter: %define enable_milter 0}

# Use rpmbuild --without debug to disable building with debug enabled (enabled by default)
%{!?_with_debug:   %{!?_without_debug: %define _with_debug --with-debug}}
%{?_with_debug:    %define enable_debug 1}
%{?_without_debug: %define enable_debug 0}

# For a full release version, don't define beta
%define beta cvs20050603
%define relsuffix p4

%define libver 1.0.0
%define rpmrel 1

# Where to put the milter initscript, if required
%{!?_initrddir: %define _initrddir %{_sysconfdir}/rc.d/init.d}

# Mandriva doesn't define the __id_u macro
%{!?__id_u: %define __id_u /bin/id -u}

Name:		libspf
Version:	%{libver}
Release:	%{?beta:0.%{beta}.}%{rpmrel}
Summary:	libspf is an implementation of the SPF specification
License:	BSD-ish
Group:		System Environment/Libraries
Url:		http://www.libspf.org/
Source:		http://www.libspf.org/files/%{name}-%{version}%{?beta:-%{beta}}.tar.bz2
Patch0:		libspf-1.0.0-p2-Makefile.patch
Patch1:		libspf-1.0.0-p4-res_query.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%if %{enable_checks}
BuildRequires:	perl
%endif
%if %{enable_milter}
BuildRequires:	sendmail-devel >= 8.12
%endif
Provides:	spf

%description
libspf is an implementation of the SPF (Sender Policy Framework)
specification as found at
http://www.ietf.org/internet-drafts/draft-mengwong-spf-00.txt
SPF allows email systems to check SPF DNS records and make sure that
an email is authorized by the administrator of the domain name that
it is coming from. This prevents email forgery, commonly used by
spammers, scammers, and email viruses/worms.

%package devel
Summary:	Libraries and header files needed to build programs that use libspf
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
The libspf-devel package contains the header files and static
libraries necessary for developing programs using the libspf (Sender
Policy Framework) library.
 
If you want to develop programs that will look up and process SPF records,
you should install libspf-devel. You also need to install the libspf package.

%package progs
Summary:		Programs for making SPF queries using libspf
Group:			Applications/Internet
Requires:		%{name} = %{version}-%{release}
Requires(post):		%{_sbindir}/alternatives
Requires(preun):	%{_sbindir}/alternatives
Requires(postun):	%{_sbindir}/alternatives

%description progs
Programs for making SPF queries and checking their results using libspf.

%if %{enable_milter}
%package milter
Summary:		Sendmail mail filter module using libspf
Group:			System Environment/Daemons
Requires:		sendmail >= 8.12, sendmail-cf >= 8.12, libspf
License:		ACME Labs Freeware License
Conflicts:		spfmilter
Requires(pre):		%{_sbindir}/useradd
Requires(post):		chkconfig >= 1.3
Requires(preun):	chkconfig >= 1.3, /sbin/service
Requires(postun):	/sbin/service, %{_sbindir}/userdel, %{_sbindir}/groupdel

%description milter
Spfmilter implements the Sender Policy Framework (http://spf.pobox.com/)
as a milter, using the libspf library.

The idea of SPF is to prevent email forgery.  Each participating
domain sets up a little definition of which hosts are allowed to send
mail claiming to be from that domain.  When another site receives
mail, it checks the permitted-senders definition for the originating
domain.  If the check fails, the mail is rejected.
%endif

%prep
%setup -q -n %{name}-%{version}%{?relsuffix:-%{relsuffix}}
: > spfmilter-whitelist
: > spfmilter-fallback
%{_bindir}/find . -depth -type d -a \( -name CVS -o -name '*.swp' \) -exec %{__rm} -rf {} \;

%build
# Bootstrap procedure after editing Makefile.am, configure.in etc.
#./configure --enable-debug --enable-spfmilter --enable-rfc-recursion --enable-pthreads
#%{__aclocal}
#%{__autoconf}
#%{__libtoolize} --automake --force
#%{__automake}

%{configure} \
%if %{enable_debug}
	--enable-debug \
%else
	--disable-debug \
%endif
%if %{enable_milter}
	--enable-spfmilter \
%else
	--disable-spfmilter \
%endif
	--enable-rfc-recursion \
	--enable-pthreads
%{__make} # %{?_smp_mflags} SMP builds are broken

%install
[ "$RPM_BUILD_ROOT" != "/" -a -n "$RPM_BUILD_ROOT" ] && %{__rm} -rf $RPM_BUILD_ROOT
%{__make} DESTDIR=$RPM_BUILD_ROOT install
%{__ln_s} spfqtool $RPM_BUILD_ROOT%{_bindir}/spfquery.libspf

%if %{enable_milter}
%{__mkdir} -p $RPM_BUILD_ROOT{%{_sysconfdir}/{sysconfig,mail},%{_initrddir}}
%{__install} -m 755 docs/spfmilter/spf-redhat.init $RPM_BUILD_ROOT%{_initrddir}/spfmilter
%{__install} -m 755 docs/spfmilter/spfmilter.sysconfig $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/spfmilter
%{__install} -m 644 spfmilter-whitelist $RPM_BUILD_ROOT%{_sysconfdir}/mail
%{__install} -m 644 spfmilter-fallback $RPM_BUILD_ROOT%{_sysconfdir}/mail
%{__install} -d -m 700 $RPM_BUILD_ROOT%{_localstatedir}/run/spfmilter
%endif

%if %{enable_checks}
# Delete the following line for builds on legacy rpmbuild versions without %%check (rpm < 4.1.1)
%check
cd src/spfqtool
%{__perl} test.pl | %{_bindir}/tee testresults
%{__grep} '^not ok' testresults && exit 1
exit 0
%endif

%clean
[ "$RPM_BUILD_ROOT" != "/" -a -n "$RPM_BUILD_ROOT" ] && %{__rm} -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post progs
%{_sbindir}/alternatives --install %{_bindir}/spfquery spf %{_bindir}/spfquery.libspf 90
exit 0

%preun progs
if [ $1 = 0 ]; then
	%{_sbindir}/alternatives --remove spf %{_bindir}/spfquery.libspf
fi
exit 0

%postun progs
if [ "$1" -ge "1" ]; then
	spf=`%{_bindir}/readlink /etc/alternatives/spf`
	if [ "$spf" == "%{_bindir}/spfquery.libspf" ]; then
		%{_sbindir}/alternatives --set spf %{_bindir}/spfquery.libspf
	fi
fi
exit 0

%if %{enable_milter}
%pre milter
# Create user spfmilt to run the milter
%{_sbindir}/useradd -r -d /etc/mail -s /sbin/nologin \
	-c "SPF Milter" spfmilt >/dev/null 2>&1 || :
exit 0

%post milter
/sbin/chkconfig --add spfmilter
exit 0

%preun milter
if [ $1 = 0 ]; then
	/sbin/service spfmilter stop >/dev/null 2>&1 || :
	/sbin/chkconfig --del spfmilter
fi
exit 0

%postun milter
if [ $1 -eq 0 ]; then
	%{__rm} -rf %{_localstatedir}/run/spfmilter
	%{_sbindir}/userdel spfmilt >/dev/null 2>&1 || :
	%{_sbindir}/groupdel spfmilt >/dev/null 2>&1 || :
else
	/sbin/service spfmilter condrestart >/dev/null 2>&1 || :
fi
exit 0
%endif

%files
%defattr(-,root,root,0755)
%{_libdir}/libspf-1.0.so.*
%doc AUTHORS README LICENSE TODO FAQ examples docs/history docs/RFC

%files devel
%defattr(-,root,root,0755)
%{_includedir}/spf.h
%{_libdir}/libspf.a
%{_libdir}/libspf.la
%{_libdir}/libspf.so
%doc docs/API docs/Courier-MTA docs/Postfix docs/qmail docs/README docs/Sendmail patches
%exclude %{_includedir}/_stdint.h

%files progs
%defattr(-,root,root,0755)
%{_bindir}/spfqtool
%{_bindir}/spfquery.libspf
%doc docs/spfqtool src/spfqtool/INSTALL
%exclude %{_bindir}/spfqtool_static

%if %{enable_milter}
%files milter
%defattr(-,root,root,0755)
%{_sbindir}/spfmilter
%{_mandir}/man8/spfmilter.8*
%{_initrddir}/spfmilter
%dir %attr(-,spfmilt,spfmilt) %{_localstatedir}/run/spfmilter
%config (noreplace) %{_sysconfdir}/sysconfig/spfmilter
%config (noreplace) %{_sysconfdir}/mail/spfmilter-whitelist
%config (noreplace) %{_sysconfdir}/mail/spfmilter-fallback
%doc src/spfmilter/AUTHORS src/spfmilter/CHANGELOG src/spfmilter/README docs/spfmilter/spfmilter-HOWTO
%exclude %{_sbindir}/spfmilter_static
%endif

%changelog
* Fri Jun  3 2005 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20050603.1
- another CVS snapshot
- use %%exclude directives in file list instead of deleting installed files
- use Requires() style dependencies instead of PreReq for scriptlets
- remove fix for broken tests, no longer needed
- add libspf-1.0.0-p4-res_query.patch (included in tarball) to fix new
  RHEL3.x86_64 breakage

* Mon May  9 2005 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20050509.1
- another CVS snapshot

* Fri Apr 29 2005 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20050429.1
- another CVS snapshot
- updated spfmilter Makefile patch
- add --enable-rfc-recursion configure option for RFC compliance
- add fix for broken tests due to wrong IP addresses
- remove bogus header file %{_includedir}/_stdint.h

* Fri Mar 04 2005 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20050304.1
- another CVS snapshot

* Tue Feb 08 2005 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20050208.1
- another CVS snapshot
- stop spfmilter service before removal of package
- restart milter after package upgrade
- remove %{_localstatedir}/run/spfmilter and contents after removal of package
- replace _var with _localstatedir macro
- replace /etc with _sysconfdir macro

* Thu Dec 09 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20041209.1
- another CVS snapshot

* Thu Nov 25 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20041125.1
- another CVS snapshot
- add another patch to remove bits of spfmilter/Makefile.am that are not
  only not necessary, but that can break things by being there

* Tue Oct 26 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20041026.1
- another CVS snapshot

* Thu Oct 21 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20041021.1
- another CVS snapshot
- spfqtool docs added to -progs subpackage
- alternatives precedence bumped up to 90 (above libspf2, which is buggy)

* Fri Oct  8 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20041008.1
- another CVS snapshot

* Thu Sep 30 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040930.1
- another CVS snapshot

* Mon Sep 27 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040927.1
- another CVS snapshot
- include patch libspf-1.0.0-spfmilter-Makefile.patch needed to get
  spfmilter manpage included by "make dist"

* Fri Sep 17 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040917.1
- another CVS snapshot, tarball created using "make dist", so enormous
  autotools patch no longer needed
- all other current patches incorporated upstream and removed from RPM

* Thu Sep 16 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040916.1
- another CVS snapshot
- initscript incorporated upstream, but sysconfig file needs patch to fix
  pidfile location
- test suite no longer broken
- newline-stripping now done upstream so patch no longer applied, but kept
  around in case something got missed
- reshuffled documentation

* Wed Sep 15 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040914.1
- another CVS snapshot
- improved, simplified initscript puts pid file in /var/run
- newlines stripped from inserted headers to stop sendmail complaining
  about them

* Mon Sep  6 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040906.1
- another CVS snapshot
- enable reentrant mode unconditionally - it's just good practice

* Wed Sep  1 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.cvs20040901.1
- update to latest CVS version
- enable re-entrant mode if building the milter
- add patch to fix syntax error in configure script

* Wed Aug 18 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.RC5.2
- use patch instead of requiring up to date autotools for building
- updated spfmilter Makefile.am patch to remove references to installed libspf
- turn off SMP make option, seems to to be reliable

* Mon Aug  9 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.RC5.1
- RC5 final?
- spf.h now in %{_includedir} rather than %{_includedir}/spf
- most documents moved to devel package

* Tue Aug  3 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.RC5.080304.1
- next release candidate
- spf.h moved from libspf/ into spf/
- add -milter subpackage, optionally disabled with --without milter

* Tue Aug  3 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.RC5.072804.1
- next release candidate
- Makefile patch incorporated upstream, so removed from package
- spfquery renamed to spfqtool
- use alternatives from %%{_sbindir} rather than /usr/sbin
- libspf now builds cleanly out of the box, so the autotools chain
  no longer needs to be run

* Tue Jul 27 2004 Paul Howarth <paul@city-fan.org> 1.0.0-0.RC4.1
- update to revised RC4 package (why not RC5?!)
- Use `alternatives' so that the spfquery program can co-exist
  with versions from other implementations
- remove CHANGELOG from docs
- add AUTHORS and Docs/RFC to docs
- fix Makefile breakage for all-local rules with DESTDIR

* Sun Jul 18 2004 Paul Howarth <paul@city-fan.org> 1_0_0-0.RC4.0
- update to RC4
- put libspf.{so,la} in devel package to aid resolution of
  library requirements for dependent packages

* Wed Jul 14 2004 Paul Howarth <paul@city-fan.org> 1_0_0-0.RC3k.0
- update to RC3k
- description text expanded
- rerun entire autotools chain to get correct library names

* Thu Jul 08 2004 Paul Howarth <paul@city-fan.org> 1_0_0-0.RC3d.0
- Initial RPM build.
